Enum libp2p_kad::KademliaEvent [−][src]
pub enum KademliaEvent {
InboundPutRecordRequest {
source: PeerId,
connection: ConnectionId,
record: Record,
},
InboundAddProviderRequest {
record: ProviderRecord,
},
InboundRequestServed {
request: InboundRequest,
},
OutboundQueryCompleted {
id: QueryId,
result: QueryResult,
stats: QueryStats,
},
RoutingUpdated {
peer: PeerId,
is_new_peer: bool,
addresses: Addresses,
bucket_range: (Distance, Distance),
old_peer: Option<PeerId>,
},
UnroutablePeer {
peer: PeerId,
},
RoutablePeer {
peer: PeerId,
address: Multiaddr,
},
PendingRoutablePeer {
peer: PeerId,
address: Multiaddr,
},
}Expand description
The events produced by the Kademlia behaviour.
Variants
A peer sent a KademliaHandlerIn::PutRecord request and filtering is enabled.
See KademliaStoreInserts and KademliaConfig::set_record_filtering.
Fields of InboundPutRecordRequest
A peer sent a KademliaHandlerIn::AddProvider request and filtering KademliaStoreInserts::FilterBoth is enabled.
See KademliaStoreInserts and KademliaConfig::set_record_filtering for details..
Fields of InboundAddProviderRequest
record: ProviderRecordAn inbound request has been received and handled.
Fields of InboundRequestServed
request: InboundRequestAn outbound query has produced a result.
Fields of OutboundQueryCompleted
id: QueryIdThe ID of the query that finished.
result: QueryResultThe result of the query.
stats: QueryStatsExecution statistics from the query.
The routing table has been updated with a new peer and / or address, thereby possibly evicting another peer.
Fields of RoutingUpdated
peer: PeerIdThe ID of the peer that was added or updated.
is_new_peer: boolWhether this is a new peer and was thus just added to the routing table, or whether it is an existing peer who’s addresses changed.
addresses: AddressesThe full list of known addresses of peer.
bucket_range: (Distance, Distance)Returns the minimum inclusive and maximum inclusive Distance for
the bucket of the peer.
old_peer: Option<PeerId>The ID of the peer that was evicted from the routing table to make room for the new peer, if any.
A peer has connected for whom no listen address is known.
If the peer is to be added to the routing table, a known
listen address for the peer must be provided via Kademlia::add_address.
Fields of UnroutablePeer
peer: PeerIdA connection to a peer has been established for whom a listen address
is known but the peer has not been added to the routing table either
because KademliaBucketInserts::Manual is configured or because
the corresponding bucket is full.
If the peer is to be included in the routing table, it must
must be explicitly added via Kademlia::add_address, possibly after
removing another peer.
See Kademlia::kbucket for insight into the contents of
the k-bucket of peer.
A connection to a peer has been established for whom a listen address is known but the peer is only pending insertion into the routing table if the least-recently disconnected peer is unresponsive, i.e. the peer may not make it into the routing table.
If the peer is to be unconditionally included in the routing table,
it should be explicitly added via Kademlia::add_address after
removing another peer.
See Kademlia::kbucket for insight into the contents of
the k-bucket of peer.