Enum libp2p_kad::PutRecordPhase [−][src]
pub enum PutRecordPhase {
GetClosestPeers,
PutRecord {
success: Vec<PeerId>,
get_closest_peers_stats: QueryStats,
},
}Expand description
The phases of a QueryInfo::PutRecord query.
Variants
The query is searching for the closest nodes to the record key.
The query is replicating the record to the closest nodes to the key.
Fields of PutRecord
success: Vec<PeerId>A list of peers the given record has been successfully replicated to.
get_closest_peers_stats: QueryStatsQuery statistics from the finished GetClosestPeers phase.