Enum libp2p_kad::kbucket::Entry [−][src]
pub enum Entry<'a, TPeerId, TVal> {
Present(PresentEntry<'a, TPeerId, TVal>, NodeStatus),
Pending(PendingEntry<'a, TPeerId, TVal>, NodeStatus),
Absent(AbsentEntry<'a, TPeerId, TVal>),
SelfEntry,
}Expand description
A reference into a single entry of a KBucketsTable.
Variants
Present(PresentEntry<'a, TPeerId, TVal>, NodeStatus)The entry is present in a bucket.
Tuple Fields of Present
0: PresentEntry<'a, TPeerId, TVal>1: NodeStatusPending(PendingEntry<'a, TPeerId, TVal>, NodeStatus)The entry is pending insertion in a bucket.
Tuple Fields of Pending
0: PendingEntry<'a, TPeerId, TVal>1: NodeStatusAbsent(AbsentEntry<'a, TPeerId, TVal>)The entry is absent and may be inserted.
Tuple Fields of Absent
0: AbsentEntry<'a, TPeerId, TVal>The entry represents the local node.
Implementations
Creates an immutable by-reference view of the entry.
Returns None if the entry is neither present in a bucket nor
pending insertion into a bucket.
Returns the key of the entry.
Returns None if the Key used to construct this Entry is not a valid
key for an entry in a bucket, which is the case for the local_key of
the KBucketsTable referring to the local node.