pub struct MemoryStoreConfig {
pub max_records: usize,
pub max_value_bytes: usize,
pub max_providers_per_key: usize,
pub max_provided_keys: usize,
}Expand description
Configuration for a MemoryStore.
Fields
max_records: usizeThe maximum number of records.
max_value_bytes: usizeThe maximum size of record values, in bytes.
max_providers_per_key: usizeThe maximum number of providers stored for a key.
This should match up with the chosen replication factor.
max_provided_keys: usizeThe maximum number of provider records for which the local node is the provider.