pub struct Addresses { /* private fields */ }Expand description
A non-empty list of (unique) addresses of a peer in the routing table.
Implementations
Sourceimpl Addresses
impl Addresses
Sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Multiaddr>
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Multiaddr>
Returns a mutable iterator over the addresses.
Sourcepub fn remove(&mut self, addr: &Multiaddr, mode: Remove) -> Result<(), ()>
pub fn remove(&mut self, addr: &Multiaddr, mode: Remove) -> Result<(), ()>
Removes the given address from the list.
Returns Ok(()) if the address is either not in the list or was found and
removed. Returns Err(()) if the address is the last remaining address,
which cannot be removed.
An address should only be removed if is determined to be invalid or otherwise unreachable.